@@ -1,7 +1,7 @@
 package Pcore::App;
 
 use Pcore -role, -const;
-use Pcore::Service::Nginx;
+use Pcore::API::Nginx;
 use Pcore::HTTP::Server;
 use Pcore::App::Router;
 use Pcore::App::API;
@@ -168,7 +168,7 @@ sub nginx_cfg ($self) {
 }
 
 sub start_nginx ($self) {
-    $self->{nginx} = Pcore::Service::Nginx->new;
+    $self->{nginx} = Pcore::API::Nginx->new;
 
     $self->{nginx}->add_vhost( 'vhost', $self->nginx_cfg );    # if !$self->{nginx}->is_vhost_exists('vhost');
 
